==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctriggerlist.h <==
/***************************************************************************
                          ctriggerlist.h  -  trigger list
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne oct 13 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTRIGGERLIST_H
#define CTRIGGERLIST_H

/*
Current status of cTriggerList class (Oct 13, 2002):
 - requested functionality implemented
 - new features may still be added
 - code seems to work
*/

#include "csaveablelist.h"

#include <qdatetime.h>

class cSession;
class cTextChunk;

/**
List of triggers; knows how to save itself.
  *@author Tomas Mecir
  */

class cTriggerList : public cSaveableList  {
   Q_OBJECT
public: 
  cTriggerList (QString filename, cSession *_sess);
  ~cTriggerList ();
  /** This function does absolutely nothing. */
  virtual void newString () {};
  /** Sends these commands via cCmdProcessor. */
  virtual void processCommands (const QStringList &commands);
  /** Perform matching of string against items of the list. Each match produces command(s),
  which are passed to processCommands() */
  virtual void matchString (cTextChunk *line);
  bool detectingPrompt () { return detprompt; };
  void setDetectingPrompt (bool val) { detprompt = val; };
  
  /** rewrite text - called by rewrite triggers */
  void rewriteText (int pos, int len, const QString &newtext);
protected:
  int count;
  QTime time;
  virtual void processRecursion ();
  bool detprompt,listenabled;
  
  cTextChunk *curline;
  QString plainText;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctriggerlist.h <==
/***************************************************************************
                          ctriggerlist.h  -  trigger list
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne oct 13 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTRIGGERLIST_H
#define CTRIGGERLIST_H

/*
Current status of cTriggerList class (Oct 13, 2002):
 - requested functionality implemented
 - new features may still be added
 - code seems to work
*/

#include "csaveablelist.h"

#include <qdatetime.h>

class cSession;
class cTextChunk;

/**
List of triggers; knows how to save itself.
  *@author Tomas Mecir
  */

class cTriggerList : public cSaveableList  {
   Q_OBJECT
public: 
  cTriggerList (QString filename, int sess);
  ~cTriggerList ();
  /** This function does absolutely nothing. */
  virtual void newString () {};
  /** Sends these commands via cCmdProcessor. */
  virtual void processCommands (const QStringList &commands);
  /** Perform matching of string against items of the list. Each match produces command(s),
  which are passed to processCommands() */
  virtual void matchString (cTextChunk *line);
  bool detectingPrompt () { return detprompt; };
  void setDetectingPrompt (bool val) { detprompt = val; };
  
  /** rewrite text - called by rewrite triggers */
  void rewriteText (int pos, int len, const QString &newtext);
protected:
  int count;
  QTime time;
  virtual void processRecursion ();
  bool detprompt,listenabled;
  
  cTextChunk *curline;
  QString plainText;
  
  cExpResolver *resolver;
};

#endif
